#!/usr/bin/python3
import os

# This script uses src.svg and generates svg files for each defined color
# It uses the following color table to do so:

SRC = {"folder":"eeca8f","backfolder":"c89e6b","paper":"e8e8e8","emblem":"575757"}
VARIANTS = []

# Blue
VARIANTS.append({"name":"Blue","folder":"5294e2","backfolder":"4877b1","paper":"e4e4e4","emblem":"1d344f"})
VARIANTS.append({"name":"Aqua","folder":"57b8ec","backfolder":"147eb8","paper":"e4e4e4","emblem":"106796"})
VARIANTS.append({"name":"Teal","folder":"45abb7","backfolder":"35818a","paper":"e4e4e4","emblem":"eaeaea"})
VARIANTS.append({"name":"Green","folder":"50c16f","backfolder":"1f953f","paper":"e4e4e4","emblem":"2f3e1f"})
VARIANTS.append({"name":"Sand","folder":"f9c470","backfolder":"e0a84f","paper":"e4e4e4","emblem":"55524c"})
VARIANTS.append({"name":"Grey","folder":"aaaaaa","backfolder":"727272","paper":"ffffff","emblem":"4f4f4f"})
VARIANTS.append({"name":"Orange","folder":"ff804f","backfolder":"f2632a","paper":"e4e4e4","emblem":"4a4a4a"})
VARIANTS.append({"name": "Red","folder":"f54f54","backfolder":"ca0f14","paper":"e4e4e4","emblem":"4d1c1c"})
VARIANTS.append({"name":"Pink","folder":"f26a9a","backfolder":"cf2f67","paper":"e4e4e4","emblem":"542233"})
VARIANTS.append({"name":"Purple","folder":"a27ae4","backfolder":"7240c3","paper":"e4e4e4","emblem":"2c1e44"})
VARIANTS.append({"name":"Cyan","folder":"00bcd4","backfolder":"0096aa","paper":"e4e4e4","emblem":"00424a"})
VARIANTS.append({"name":"Navy","folder":"b8d8eb","backfolder":"004988","paper":"f4f4f4","emblem":"081f2d"})
VARIANTS.append({"name":"Yaru","folder":"676767","backfolder":"973552","paper":"ff7446","emblem":"e4e4e4"})

for filename in os.listdir("."):
    if filename.endswith(".svg"):
        if filename not in ["extra.svg", "src.svg"]:
            os.remove(filename)

for variant in VARIANTS:
    name = variant["name"]
    os.system(f"cp src.svg {name}.svg")
    for key in SRC.keys():
        src_color = SRC[key]
        color = variant[key]
        if src_color != color:
            os.system("sed -i 's/%s/%s/g' %s.svg" % (src_color, color, name))



#!/usr/bin/python3
import os
import subprocess
import sys

sizes = ["16", "22", "24", "32", "48", "64", "96", "128"]

def generate_color(color):
    source = f"{color}.svg"
    green_dir = "../../usr/share/icons/Mint-Y"
    if color == "Green":
        theme_dir = green_dir
        os.system(f"mkdir -p {theme_dir}")
    else:
        theme_dir = "../../usr/share/icons/Mint-Y-%s" % color
        os.system(f"mkdir -p {theme_dir}")
        os.system(f"rm -rf {theme_dir}/*")
        os.system(f"cp -R {green_dir}/places {theme_dir}/")
        os.system(f"rm -rf {theme_dir}/places/symbolic")
        os.system(f"sed s/COLOR/{color}/g index.theme > {theme_dir}/index.theme ")

    for size in sizes:
        icon_dir = os.path.join(theme_dir, "places", size)
        icon_dir_2x = os.path.join(theme_dir, "places", size + "@2x")
        os.system("mkdir -p %s" % icon_dir)
        os.system("mkdir -p %s" % icon_dir_2x)
        names = subprocess.check_output("inkscape -S %s | grep -E \"_%s\" | sed 's/\,.*$//'" % (source, size), shell=True).decode("UTF-8")

        handles = []
        for name in names.split("\n"):

            if "_" in name:
                icon_name = name.replace("_%s" % size, "")
                icon_path = os.path.join(icon_dir, icon_name + ".png")
                print("Rendering %s" % icon_path)
                handle = subprocess.Popen("inkscape --export-id=%s \
                               --export-id-only \
                               --export-filename=%s %s >/dev/null \
                     && optipng -o7 --quiet %s" % (name, icon_path, source, icon_path), shell=True)
                handles.append(handle)

                icon_path = os.path.join(icon_dir_2x, icon_name + ".png")
                print("Rendering %s" % icon_path)
                handle = subprocess.Popen("inkscape --export-id=%s \
                               --export-id-only \
                               --export-dpi=192 \
                               --export-filename=%s %s >/dev/null \
                     && optipng -o7 --quiet %s" % (name, icon_path, source, icon_path), shell=True)
                handles.append(handle)

        n = len(handles)
        for handle in handles:
            print("waiting for processes.... %d" % n)
            n-=1
            handle.wait()

def parse_arg(arg):
    if arg == "All":
        os.system("rm -rf ../../usr/share/icons/Mint-Y-*")
        for filename in sorted(os.listdir(".")):
            if filename.endswith(".svg") and filename not in ["extra.svg", "src.svg"]:
                color = filename.replace(".svg", "")
                generate_color(color)
    else:
        generate_color(arg)

def usage():
    print ("Usage: render_places.py color \n\
    color can be a particular color or All.")
    sys.exit(1)

if len(sys.argv) != 2:
    usage()
else:
    parse_arg(sys.argv[1])
